==> nextcloud-app-calendar-1.5.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/eu.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Egutegia",
    "%s has published the calendar »%s«" : "%sk »%s« egutegia publikatu du",
    "Hello," : "Kaixo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Jakinarazi nahi dizugu %sk »%s« egutegia publikatu duela",
    "Open »%s«" : " »%s« ireki",
    "Cheers!" : "Ondo segi!",
    "Recipient" : "Jasotzailea",
    "Too many redirects. Aborting ..." : "Berbideraketa gehiegi. Abortatzen...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Urruneko zerbitzariak ez digu egutegiari sarbiderik eman ({$s} HTTP errorea)",
    "Error connecting to remote server" : "Urruneko zerbitzarira konektatzean errorea",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Edukia urruneko zerbitzarian eskatzean errorea eman du. Ziurtagiri desegokia erabiltzeagatik izan daiteke.",
    "Error requesting resource on remote server" : "Errorea edukia urruneko zerbitzarian eskatzean",
    "Individual" : "Bakarkakoa",
    "Group" : "Taldea",
    "Resource" : "Edukia",
    "Room" : "Gela",
    "Unknown" : "Ezezaguna",
    "Required" : "Beharrezkoa",
    "Optional" : "Aukerakoa",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ordu-zona ezezagunean zaude ({tz}), UTCra erabiliko da",
    "Please create a calendar first." : "Aurretik, egutegi bat sortu, mesedez.",
    "New event" : "Sarrera berria",
    "CalDAV address for clients" : "Bezeroentzako CalDAV helbidea",
    "Error saving WebCal-calendar" : "WebCal-egutegia gordetzean errorea",
    "WebDAV address for subscriptions" : "Harpidetzak egiteko WebDAV helbidea ",
    "Email has been sent." : "Eposta bidali da",
    "There was an issue while sending your email." : "Eposta bidaltzean errorea egon da",
    "group" : "taldea",
    "Details" : "Xehetasunak",
    "Attendees" : "Partaideak",
    "Reminders" : "Oroigarriak",
    "Repeating" : "Errepikapena",
    "When shared show full event" : "Partekatzean gertaera osoa erakutsi",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean gertaera hau izkutatu",
    "Confirmed" : "Baieztatua",
    "Tentative" : "Saiakera",
    "Cancelled" : "Ezeztatua",
    "Please add a title." : "Izenburua gehitu",
    "Please select a calendar." : "Egutegia hautatu",
    "The event can not end before it starts." : "Gertaera ezin da bukatu hasi baino lehen",
    "Global" : "Globala",
    "None" : "Ezer",
    "Every day" : "Egunero",
    "Every week" : "Astero",
    "Every month" : "Hilabetero",
    "Every year" : "Urtero",
    "never" : "inoiz",
    "after" : "gero",
    "How about getting started by importing some calendars?" : "Ze iruditzen egutegi batzuk inportatzen hasten bagara?",
    "At time of event" : "Gertaeraren data heltzean",
    "5 minutes before" : "5 minutu lehenago",
    "10 minutes before" : "10 minutu lehenago",
    "15 minutes before" : "15 minutu lehenago",
    "30 minutes before" : "30 minutu lehenago",
    "1 hour before" : "Ordu 1 lehenago",
    "2 hours before" : "2 ordu lehenago",
    "Custom" : "Guk hautatutakoa",
    "Audio" : "Audio",
    "Email" : "Eposta",
    "Pop-up" : "Pop-up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "ordu",
    "days" : "egun",
    "week" : "aste",
    "before" : "lehenago",
    "start" : "Hasi",
    "end" : "bukatu",
    "Editing reminders of unknown type not supported." : "Ezin da formatu ezezaguna duten oroitzapenik editatu",
    "Week {number} of {year}" : "{year}ko {number} astea",
    "{type} {time} before the event starts" : "{type} {time} gertaeraa hasi baino lehen",
    "{type} {time} before the event ends" : "{type} {time} gertaeraa bukatu baino lehen",
    "{type} {time} after the event starts" : "{type} {time} gertaeraa hasi ondoren",
    "{type} {time} after the event ends" : "{type} {time} gertaeraa bukatu ondoren",
    "{type} at the event's start" : "{type} gertaeraaren hasieran",
    "{type} at the event's end" : "{type} gertaeraa bukatzean",
    "{type} at {time}" : "{type} {time}n",
    "{calendar} shared by {owner}" : "{owner}-rek parteketutako {calendar}",
    "Please enter a valid WebCal-URL" : "Baliozko WebCal-URLa sartu mesedez",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Webcal proxyan errore larria egon da. Informazio gehiagorako administradorearekin harremanetanjar zaitez ",
    "Title of the Event" : "Gertaeraren izenburua",
    "Starts" : "Hasiera",
    "Ends" : "Bukaera",
    "All day Event" : "Egun osoko gertaera",
    "Delete" : "Ezabatu",
    "Cancel" : "Ezeztatu",
    "More ..." : "Gehiago ...",
    "Create" : "Sortu",
    "Update" : "Eguneratu",
    "Close" : "Itxi",
    "Location" : "Kokapena",
    "Description" : "Deskribapena",
    "Event status" : "Gertaeraren egoera",
    "Visibility when sharing" : "Ikusgarritasuna partekatzean",
    "Export" : "Esportatu",
    "%s has published the calendar %s" : "%s-k %s egutegia publikatu du",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Jakinarazi nahi dizugu %sk {boldstart}%s{boldend} egutegia publikatu duela",
    "Click here to access it" : "Sartzeko, klik egin hemen ",
    "We wanted to inform you that %s has published the calendar %s." : "Jakinarazi nahi dizugu %sk %s egutegia publikatu duela.",
    "Click on the link below to access it" : "Sartzeko ondoko estekan klik egin ",
    "Day" : "Eguna",
    "Week" : "Astea",
    "Month" : "Hilabetea",
    "Today" : "Gaur",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Egutegi honetako gertaera batzuk apurtuta daude. Informazio gehiagorako JS kontsola kontsulta ezazu",
    "Share Calendar" : "Elkarbanatu egutegia",
    "Shared" : "Elkarbanatuta",
    "More" : "Gehiago",
    "Edit" : "Editatu",
    "Link" : "Esteka",
    "iCal link" : "iCal esteka",
    "Download" : "Deskargatu",
    "Share with users or groups" : "Erabiltzaile edo taldeekin partekatu",
    "can edit" : "editatu dezake",
    "Share link" : "Partekatu esteka",
    "Public access" : "Sarbide publikoa",
    "Email link to person" : "Esteka eposta bidez pertsonari bidali",
    "Send" : "Bidali",
    "New Calendar" : "Egutegi berria",
    "Name" : "Izena",
    "New Subscription" : "Harpidetza berria",
    "Go back" : "Atzera",
    "Go forward" : "Aurrera",
    "Calendar does not exist" : "Egutegia ez da existitzen",
    "Maybe you got a wrong link or the calendar was unshared?" : "Agian esteka apurtua dago edo egutegia ez dago iada partekatua?",
    "Edit event" : "Editatu gertaera",
    "Delete Event" : "Borratu gertaera",
    "Save Event" : "Gorde gertaera",
    "Time" : "Noiz",
    "Type" : "Mota",
    "Relative" : "Erlatiboa",
    "Absolute" : "Absolutua",
    "Repeat" : "Errepikatu",
    "times every" : "aldi ",
    "Add" : "Gehitu",
    "Email address of attendee" : "Bertaratutakoaren eposta helbidea",
    "Please add your email address in the personal settings in order to add attendees." : "Ezarpen pertsonaletan zure eposta gehitu bertaratzeko abisuak gehitzeko",
    "from" : "lekua",
    "to" : "Noiz arte",
    "This event's repeating rule is not supported yet." : "Gertakariaren errepikapen erregela ez dago oraindik inplementatuta.",
    "Support for advanced rules will be added with subsequent updates." : "Erregela aurreratuak erabiltzeko aukera hurrengo eguneraketetan gehituko da.",
    "Reset repeating rule" : "Errepikatze erregela hasieratu",
    "Repeat every ..." : "Errepikatu ...",
    "end repeat ..." : "errepikapena bukatu ...",
    "times" : "aldi",
    "Import Calendars" : "Egutegiak Inportatu",
    "Import canceled" : "Inportazioa ezeztatua",
    "Analyzing calendar" : "Egutegia analizatzen",
    "The file contains objects incompatible with the selected calendar" : "Fitxategiak hautatutako egutegiarekin bateraezinak diren objektuak ditu",
    "New calendar" : "Egutegi berria",
    "File is empty" : "Fitxategia hutsik dago",
    "Import scheduled" : "Inportazioa programatuta",
    "%s shared the calendar <strong>%s</strong> with you" : "%s-k <strong>%s</strong> egutegia zurekin partekatu du",
    "Iframe to integrate" : "Integratzeko Iframea",
    "Publish URL" : "URL-a publikatu",
    "Settings & import" : "Ezarpenak & inportazioa",
    "Skip simple event editor" : "Gertaeren editore sinplea saltatu",
    "Show week numbers" : "aste zenbakiak erakutsi",
    "Import calendar" : "Egutegia inportatu",
    "No Calendars selected for import" : "Inportatzeko Egutegitirk ez da hautatu",
    "Primary CalDAV address" : "CalDAV helbide nagusia",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV helbidea",
    "Subscribe" : "Harpidetu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/eu.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Egutegia",
    "%s has published the calendar »%s«" : "%sk »%s« egutegia publikatu du",
    "Hello," : "Kaixo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Jakinarazi nahi dizugu %sk »%s« egutegia publikatu duela",
    "Open »%s«" : " »%s« ireki",
    "Cheers!" : "Ondo segi!",
    "Recipient" : "Jasotzailea",
    "Too many redirects. Aborting ..." : "Berbideraketa gehiegi. Abortatzen...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Urruneko zerbitzariak ez digu egutegiari sarbiderik eman ({$s} HTTP errorea)",
    "Error connecting to remote server" : "Urruneko zerbitzarira konektatzean errorea",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Edukia urruneko zerbitzarian eskatzean errorea eman du. Ziurtagiri desegokia erabiltzeagatik izan daiteke.",
    "Error requesting resource on remote server" : "Errorea edukia urruneko zerbitzarian eskatzean",
    "Individual" : "Bakarkakoa",
    "Group" : "Taldea",
    "Resource" : "Edukia",
    "Room" : "Gela",
    "Unknown" : "Ezezaguna",
    "Required" : "Beharrezkoa",
    "Optional" : "Aukerakoa",
    "Does not attend" : "Ez du kaso egin",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ordu-zona ezezagunean zaude ({tz}), UTCra erabiliko da",
    "Please create a calendar first." : "Aurretik, egutegi bat sortu, mesedez.",
    "New event" : "Sarrera berria",
    "CalDAV address for clients" : "Bezeroentzako CalDAV helbidea",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Egutegi honetako gertaera batzuk apurtuta daude. Informazio gehiagorako JS kontsola kontsulta ezazu",
    "Share Calendar" : "Elkarbanatu egutegia",
    "Shared" : "Elkarbanatuta",
    "Could not save WebCal-calendar" : "Ezin da WebCal- egutegia gorde",
    "WebDAV address for subscriptions" : "Harpidetzak egiteko WebDAV helbidea ",
    "Email sent." : "Eposta bidali da",
    "Could not send your email." : "Eposta ezin da bidali",
    "group" : "taldea",
    "Details" : "Xehetasunak",
    "Attendees" : "Partaideak",
    "Reminders" : "Oroigarriak",
    "Repeating" : "Errepikapena",
    "When shared show full event" : "Partekatzean gertaera osoa erakutsi",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean gertaera hau izkutatu",
    "Confirmed" : "Baieztatua",
    "Tentative" : "Saiakera",
    "Cancelled" : "Ezeztatua",
    "Please add a title." : "Izenburua gehitu",
    "Please select a calendar." : "Egutegia hautatu",
    "The event can not end before it starts." : "Gertaera ezin da bukatu hasi baino lehen",
    "Global" : "Globala",
    "None" : "Ezer",
    "Every day" : "Egunero",
    "Every week" : "Astero",
    "Every month" : "Hilabetero",
    "Every year" : "Urtero",
    "never" : "inoiz",
    "after" : "gero",
    "How about getting started by importing some calendars?" : "Ze iruditzen egutegi batzuk inportatzen hasten bagara?",
    "At time of event" : "Gertaeraren data heltzean",
    "5 minutes before" : "5 minutu lehenago",
    "10 minutes before" : "10 minutu lehenago",
    "15 minutes before" : "15 minutu lehenago",
    "30 minutes before" : "30 minutu lehenago",
    "1 hour before" : "Ordu 1 lehenago",
    "2 hours before" : "2 ordu lehenago",
    "Custom" : "Guk hautatutakoa",
    "Audio" : "Audio",
    "Email" : "Eposta",
    "Pop-up" : "Pop-up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "ordu",
    "days" : "egun",
    "week" : "aste",
    "before" : "lehenago",
    "start" : "Hasi",
    "end" : "bukatu",
    "Editing reminders of unknown type not supported." : "Ezin da formatu ezezaguna duten oroitzapenik editatu",
    "Week {number} of {year}" : "{year}ko {number} astea",
    "Successfully imported {imported} objects" : "{imported} objektu ongi inportatu dira",
    "{type} {time} before the event starts" : "{type} {time} gertaeraa hasi baino lehen",
    "{type} {time} before the event ends" : "{type} {time} gertaeraa bukatu baino lehen",
    "{type} {time} after the event starts" : "{type} {time} gertaeraa hasi ondoren",
    "{type} {time} after the event ends" : "{type} {time} gertaeraa bukatu ondoren",
    "{type} at the event's start" : "{type} gertaeraaren hasieran",
    "{type} at the event's end" : "{type} gertaeraa bukatzean",
    "{type} at {time}" : "{type} {time}n",
    "{calendar} shared by {owner}" : "{owner}-rek parteketutako {calendar}",
    "Please enter a valid WebCal-URL" : "Baliozko WebCal-URLa sartu mesedez",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Webcal proxyan errore larria egon da. Informazio gehiagorako administradorearekin harremanetanjar zaitez ",
    "Title of the Event" : "Gertaeraren izenburua",
    "Starts" : "Hasiera",
    "Ends" : "Bukaera",
    "All day Event" : "Egun osoko gertaera",
    "Delete" : "Ezabatu",
    "Cancel" : "Ezeztatu",
    "More ..." : "Gehiago ...",
    "Create" : "Sortu",
    "Update" : "Eguneratu",
    "Close" : "Itxi",
    "Location" : "Kokapena",
    "Description" : "Deskribapena",
    "Event status" : "Gertaeraren egoera",
    "Visibility when sharing" : "Ikusgarritasuna partekatzean",
    "Export" : "Esportatu",
    "%s has published the calendar %s" : "%s-k %s egutegia publikatu du",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Jakinarazi nahi dizugu %sk {boldstart}%s{boldend} egutegia publikatu duela",
    "Click here to access it" : "Sartzeko, klik egin hemen ",
    "We wanted to inform you that %s has published the calendar %s." : "Jakinarazi nahi dizugu %sk %s egutegia publikatu duela.",
    "Click on the link below to access it" : "Sartzeko ondoko estekan klik egin ",
    "Day" : "Eguna",
    "Week" : "Astea",
    "Month" : "Hilabetea",
    "Today" : "Gaur",
    "More" : "Gehiago",
    "Edit" : "Editatu",
    "Link" : "Esteka",
    "iCal link" : "iCal esteka",
    "Download" : "Deskargatu",
    "Share with users or groups" : "Erabiltzaile edo taldeekin partekatu",
    "can edit" : "editatu dezake",
    "Share link" : "Partekatu esteka",
    "Public access" : "Sarbide publikoa",
    "Email link to person" : "Esteka eposta bidez pertsonari bidali",
    "Send" : "Bidali",
    "New Calendar" : "Egutegi berria",
    "Name" : "Izena",
    "New Subscription" : "Harpidetza berria",
    "Go back" : "Atzera",
    "Go forward" : "Aurrera",
    "Calendar does not exist" : "Egutegia ez da existitzen",
    "Maybe you got a wrong link or the calendar was unshared?" : "Agian esteka apurtua dago edo egutegia ez dago iada partekatua?",
    "Edit event" : "Editatu gertaera",
    "Delete Event" : "Borratu gertaera",
    "Save Event" : "Gorde gertaera",
    "Time" : "Noiz",
    "Type" : "Mota",
    "Relative" : "Erlatiboa",
    "Absolute" : "Absolutua",
    "Repeat" : "Errepikatu",
    "times every" : "aldi ",
    "Add" : "Gehitu",
    "Email address of attendee" : "Bertaratutakoaren eposta helbidea",
    "Please add your email address in the personal settings in order to add attendees." : "Ezarpen pertsonaletan zure eposta gehitu bertaratzeko abisuak gehitzeko",
    "from" : "lekua",
    "to" : "Noiz arte",
    "This event's repeating rule is not supported yet." : "Gertakariaren errepikapen erregela ez dago oraindik inplementatuta.",
    "Support for advanced rules will be added with subsequent updates." : "Erregela aurreratuak erabiltzeko aukera hurrengo eguneraketetan gehituko da.",
    "Reset repeating rule" : "Errepikatze erregela hasieratu",
    "Repeat every ..." : "Errepikatu ...",
    "end repeat ..." : "errepikapena bukatu ...",
    "times" : "aldi",
    "Import Calendars" : "Egutegiak Inportatu",
    "Import canceled" : "Inportazioa ezeztatua",
    "Analyzing calendar" : "Egutegia analizatzen",
    "The file contains objects incompatible with the selected calendar" : "Fitxategiak hautatutako egutegiarekin bateraezinak diren objektuak ditu",
    "New calendar" : "Egutegi berria",
    "File is empty" : "Fitxategia hutsik dago",
    "Import scheduled" : "Inportazioa programatuta",
    "%s shared the calendar <strong>%s</strong> with you" : "%s-k <strong>%s</strong> egutegia zurekin partekatu du",
    "Iframe to integrate" : "Integratzeko Iframea",
    "Publish URL" : "URL-a publikatu",
    "Settings & import" : "Ezarpenak & inportazioa",
    "Skip simple event editor" : "Gertaeren editore sinplea saltatu",
    "Show week numbers" : "aste zenbakiak erakutsi",
    "Import calendar" : "Egutegia inportatu",
    "No Calendars selected for import" : "Inportatzeko Egutegitirk ez da hautatu",
    "Primary CalDAV address" : "CalDAV helbide nagusia",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV helbidea",
    "Subscribe" : "Harpidetu"
},
"nplurals=2; plural=(n != 1);");
